@@ -347,7 +347,7 @@ class ImageGraphCut:
             pyed.setContours(1 - self.segmentation.astype(np.int8))
 
         try:
-            import audiosupport
+            from lisa import audiosupport
             audiosupport.beep()
         except:
             print("cannot open audiosupport")
